# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key: pypi-AgEIcHlwaS5vcmcCJDdmMTA1ZTM4LWQ0NTQtNDA5MC1iNTNkLTQ4ZTRiODM2OTk2MgACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiC_TDYR3-wJdiGOo0LV1XzyxZ0Gqrad5VO0KM-j6WHH1w

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/